==> mls-0.2.tar.gz: mls-0.2/src/keybind.cpp <==
/*
def MACRO key_code

set MACRO command
meta MACRO command

*.key file example
-------------------
#comment
def KEY_UP 24
def KEY_DOWN 2

set KEY_UP <up>
meta KEY_LEFT <history>
*/

#include "keybind.h"
#include "StringTokenizer.h"
#include "define.h"
#include "strutil.h"

#include <iostream>
#include <fstream>

using namespace std;
using namespace strutil;

int MLS::KeyBind::Load( const std::string &fn )
{
	string   line;	
	ifstream in(fn.c_str());
	
	if (in.fail()) return 0;
	
	map<std::string, int> definitions;
	
	while(getline(in,line))
	{
		if (line.empty() || line[0] == '#') continue;
		StringTokenizer st(line, "\t\r\n ");
	
		if (!st.Next()) continue;
		string cmd = st.Get();
		
		if (!st.Next()) continue;
		string macro = st.Get();		
		
		string param = chop(st.Rest());
		
		if (param.empty()) continue;
				
		if (cmd == "def")
		{			
			definitions[macro] = atoi(param.c_str());
		}
		else if (cmd == "set")
		{
			map<string, int>::iterator i;
			
			if (macro.size() >= 3 && macro[0]=='\'' && macro[2]=='\'') 
			{
				bindings[(int)macro[1]] = param;				
			}
			else if ((i = definitions.find(macro)) != definitions.end())
			{
				bindings[(*i).second] = param;
			}
		}
		else if (cmd == "meta")
		{
			map<std::string, int>::iterator i;			

			if (macro.size() >= 3 && macro[0]=='\'' && macro[2]=='\'') 
			{
				meta_bindings[(int)macro[1]] = param;				
			}
			else if ((i = definitions.find(macro)) != definitions.end())
			{
				meta_bindings[(*i).second] = param;
			}
		}		
	}	
	in.close();
	return 1;
}

static std::string EmptyString = "";

std::string MLS::KeyBind::GetCommand( int key )
{
	map<int, string>::iterator i;

	if ( (i = bindings.find(key)) != bindings.end() ) return (*i).second;

	return EmptyString;
}

std::string MLS::KeyBind::GetMetaCommand( int key )
{
	map<int, string>::iterator i;

	if ( (i = meta_bindings.find(key)) != meta_bindings.end() ) return (*i).second;

	return EmptyString;
}

MLS::KeyBind::KeyBind( )
{
}

MLS::KeyBind::~KeyBind( )
{
}

==> mls-0.3.tar.gz: mls-0.3/src/keybind.cpp <==
/*
def MACRO key_code

set MACRO command
meta MACRO command

*.key file example
-------------------
#comment
def KEY_UP 24
def KEY_DOWN 2

set KEY_UP <up>
meta KEY_LEFT <history>
*/

#include "keybind.h"
#include "StringTokenizer.h"
#include "define.h"
#include "strutil.h"

#include <iostream>
#include <fstream>

using namespace std;
using namespace strutil;

int MLS::KeyBind::Load( const std::string &fn )
{
	string   line;	
	ifstream in(fn.c_str());
	
	if (in.fail()) return ERROR;
	
	map<std::string, int> definitions;
	
	while(getline(in,line))
	{
		if (line.empty() || line[0] == '#') continue;
		StringTokenizer st(line, "\t\r\n ");
	
		if (!st.Next()) continue;
		string cmd = st.Get();
		
		if (!st.Next()) continue;
		string macro = st.Get();
		
		string param = chop(st.Rest());
		
		if (param.empty()) continue;
				
		if (cmd == "def")
		{			
			definitions[macro] = atoi(param.c_str());
		}
		else if (cmd == "set")
		{
			map<string, int>::iterator i;
			
			if (macro.size() >= 3 && macro[0]=='\'' && macro[2]=='\'') 
			{
				bindings[(int)macro[1]] = param;				
			}
			else if ((i = definitions.find(macro)) != definitions.end())
			{
				bindings[(*i).second] = param;
			}
		}
		else if (cmd == "meta")
		{
			map<std::string, int>::iterator i;			

			if (macro.size() >= 3 && macro[0]=='\'' && macro[2]=='\'') 
			{			
				meta_bindings[(int)macro[1]] = param;				
			}
			else if ((i = definitions.find(macro)) != definitions.end())
			{
				meta_bindings[(*i).second] = param;
			}
		}		
	}	
	in.close();
	return SUCCESS;
}

static std::string EmptyString = "";

std::string MLS::KeyBind::GetCommand( int key )
{
	map<int, string>::iterator i;

	if ( (i = bindings.find(key)) != bindings.end() ) return (*i).second;
	
	if ( 'a' <= key && key <= 'z'&& (i = bindings.find(key-'a'+'A')) != bindings.end()) return (*i).second;
	
	if ( 'A' <= key && key <= 'Z'&& (i = bindings.find(key-'A'+'a')) != bindings.end()) return (*i).second;
	

	return EmptyString;
}

std::string MLS::KeyBind::GetMetaCommand( int key )
{
	map<int, string>::iterator i;

	if ( (i = meta_bindings.find(key)) != meta_bindings.end() ) return (*i).second;
	
	if ( 'a' <= key && key <= 'z'&& (i = meta_bindings.find(key-'a'+'A')) != meta_bindings.end()) return (*i).second;
	
	if ( 'A' <= key && key <= 'Z'&& (i = meta_bindings.find(key-'A'+'a')) != meta_bindings.end()) return (*i).second;

	return EmptyString;
}

MLS::KeyBind::KeyBind( )
{
}

MLS::KeyBind::~KeyBind( )
{
}
